% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{Coord}
\alias{Coord}
\title{Coord: position transformation for normalized coordinates}
\usage{
Coord(name = character(0))
}
\arguments{
\item{name}{Human-readable coord name.}
}
\value{
An S7 object of class \code{Coord}, the base class for coordinate systems.
}
\description{
Base class for coordinate systems. A coord receives positions already
normalized to [0, 1] by the scales and returns (possibly transformed)
normalized positions. Cartesian is the identity; polar / flipped / 3D
coords will override this seam without touching scales or geoms.
}
