% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats.R
\name{stat_ydensity}
\alias{stat_ydensity}
\title{Mirrored y-density for violins}
\usage{
stat_ydensity(width = 0.9, n = 101)
}
\arguments{
\item{width}{Maximum violin width in x slot units.}

\item{n}{Number of density evaluation points.}
}
\value{
A \code{StatYdensity} object, to pass as a layer's \code{stat}.
}
\description{
Mirrored y-density for violins
}
