% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats.R
\name{stat_smooth}
\alias{stat_smooth}
\title{Fitted trend line with confidence band}
\usage{
stat_smooth(method = "loess", se = TRUE, n = 80, level = 0.95)
}
\arguments{
\item{method}{\code{"loess"} (default) or \code{"lm"}.}

\item{se}{Include the confidence band.}

\item{n}{Number of grid points.}

\item{level}{Confidence level.}
}
\value{
A \code{StatSmooth} object, to pass as a layer's \code{stat}.
}
\description{
Fitted trend line with confidence band
}
