% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats-special.R
\name{stat_roc}
\alias{stat_roc}
\title{Empirical ROC curve}
\usage{
stat_roc()
}
\value{
A \code{StatROC} object, to pass as a layer's \code{stat}.
}
\description{
Empirical ROC curve
}
