% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_step}
\alias{geom_step}
\title{Step layer (staircase line)}
\usage{
geom_step(
  mapping = NULL,
  data = NULL,
  color = NULL,
  linewidth = NULL,
  alpha = NULL,
  dash = NULL
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{linewidth}{Stroke width in px.}

\item{dash}{SVG dash pattern (e.g. \code{"4,3"}); \code{""} for solid.}
}
\value{
A \link{Layer}.
}
\description{
Step layer (staircase line)
}
