% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms-special.R
\name{geom_waterfall}
\alias{geom_waterfall}
\title{Waterfall chart layer (running total of signed changes)}
\usage{
geom_waterfall(
  mapping = NULL,
  data = NULL,
  alpha = NULL,
  width = 0.8,
  color_pos = NULL,
  color_neg = NULL
)
}
\arguments{
\item{mapping, data, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{width}{Bar width in x slot units.}

\item{color_pos, color_neg}{Bar colors for increases/decreases.}
}
\value{
A \link{Layer}.
}
\description{
Categories plot in level order; pass
\code{x = factor(x, levels = unique(x))} to keep them in data order.
}
