% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{scale_color_gradient}
\alias{scale_color_gradient}
\title{Set the continuous color gradient}
\usage{
scale_color_gradient(low = "#1A2E59", high = "#5FD0A5", name = NULL)
}
\arguments{
\item{low, high}{Gradient endpoint colors.}

\item{name}{Optional legend title.}
}
\value{
A \code{ColorScale} object to add with \code{+}.
}
\description{
Set the continuous color gradient
}
\examples{
ggnext(iris, aes(Sepal.Length, Sepal.Width, color = Petal.Length)) +
  geom_point() +
  scale_color_gradient(low = "#FFF3B0", high = "#9E2A2B")
}
