% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/labels.R
\name{ylab}
\alias{ylab}
\title{Set the y axis title}
\usage{
ylab(label)
}
\arguments{
\item{label}{Axis title text.}
}
\value{
A \link{Labels} object to add to a plot with \code{+}.
}
\description{
Set the y axis title
}
