% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_vline}
\alias{geom_vline}
\title{Vertical reference line}
\usage{
geom_vline(
  xintercept,
  color = NULL,
  linewidth = NULL,
  alpha = NULL,
  dash = NULL
)
}
\arguments{
\item{xintercept}{Numeric vector of x positions.}

\item{color, linewidth, alpha}{Styling.}

\item{dash}{Dash pattern; defaults to \code{"4,3"} (dashed).}
}
\value{
A \link{Layer}.
}
\description{
Vertical reference line
}
