% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{compute_stat}
\alias{compute_stat}
\title{Apply a stat's transformation to evaluated aesthetic values}
\usage{
compute_stat(stat, ...)
}
\arguments{
\item{stat}{A \link{Stat} subclass instance.}

\item{...}{Method arguments; all methods take \code{values} (named list of
evaluated aesthetic vectors).}
}
\value{
Named list of (possibly transformed) aesthetic vectors.
}
\description{
Methods receive \code{values}, a named list of evaluated aesthetic vectors,
and return a named list of (possibly transformed) aesthetic vectors.
}
