% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats-ml.R
\name{stat_pr}
\alias{stat_pr}
\title{Empirical precision-recall curve}
\usage{
stat_pr()
}
\value{
A \code{StatPR} object, to pass as a layer's \code{stat}.
}
\description{
Empirical precision-recall curve
}
