% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{Theme}
\alias{Theme}
\alias{theme}
\title{Customize theme settings}
\usage{
Theme(
  name = character(0),
  background = character(0),
  panel_fill = character(0),
  grid_color = character(0),
  grid_color_minor = character(0),
  axis_color = character(0),
  label_color = character(0),
  title_color = character(0),
  subtitle_color = character(0),
  strip_fill = character(0),
  strip_color = character(0),
  legend_text_color = character(0),
  panel_border = character(0),
  font = character(0),
  title_font = character(0),
  tick_font_size = integer(0),
  title_font_size = integer(0),
  plot_title_size = integer(0),
  plot_subtitle_size = integer(0),
  caption_size = integer(0),
  strip_font_size = integer(0),
  legend_font_size = integer(0),
  title_face = character(0),
  tick_len = integer(0),
  grid_major_x = logical(0),
  grid_major_y = logical(0),
  axis_line_x = logical(0),
  axis_line_y = logical(0),
  ticks_x = logical(0),
  ticks_y = logical(0),
  axis_text_x = logical(0),
  axis_text_y = logical(0),
  axis_title_x = logical(0),
  axis_title_y = logical(0),
  legend_position = character(0),
  point_palette = character(0),
  gradient_low = character(0),
  gradient_high = character(0)
)

theme(..., base = NULL)
}
\arguments{
\item{name}{Preset name (informational).}

\item{background}{Plot background color.}

\item{panel_fill}{Panel (data area) background color.}

\item{grid_color}{Major gridline color; \code{""} hides major gridlines.}

\item{grid_color_minor}{Minor gridline color; \code{""} (default) draws none.}

\item{axis_color}{Axis line and tick color.}

\item{label_color}{Tick label and axis title color.}

\item{title_color}{Plot title color.}

\item{subtitle_color}{Subtitle and caption color.}

\item{strip_fill, strip_color}{Facet strip background and text colors.}

\item{legend_text_color}{Legend label color.}

\item{panel_border}{Panel border color; \code{""} (default) draws none.}

\item{font}{CSS font-family stack used for all text.}

\item{title_font}{Font stack for the plot title; \code{""} inherits \code{font}.}

\item{tick_font_size}{Tick label size (px).}

\item{title_font_size}{Axis title size (px).}

\item{plot_title_size, plot_subtitle_size, caption_size}{Title block sizes (px).}

\item{strip_font_size}{Facet strip label size (px).}

\item{legend_font_size}{Legend label size (px).}

\item{title_face}{Plot title weight: \code{"bold"} or \code{"normal"}.}

\item{tick_len}{Tick mark length (px).}

\item{grid_major_x, grid_major_y}{Draw major gridlines per axis.}

\item{axis_line_x, axis_line_y}{Draw the axis lines.}

\item{ticks_x, ticks_y}{Draw tick marks.}

\item{axis_text_x, axis_text_y}{Draw tick labels.}

\item{axis_title_x, axis_title_y}{Draw axis titles.}

\item{legend_position}{\code{"right"}, \code{"bottom"}, or \code{"none"}.}

\item{point_palette}{Optional character vector overriding the discrete
color palette for this plot.}

\item{gradient_low, gradient_high}{Optional continuous-gradient endpoints.}

\item{...}{Named \link{Theme} properties to override, e.g.
\code{theme(panel_fill = "white", grid_color = "grey85")}.}

\item{base}{A \link{Theme} to start from; defaults to \code{\link[=theme_ggnext]{theme_ggnext()}}.}
}
\value{
A \link{Theme} to add to a plot with \code{+}.
}
\description{
Overrides individual theme settings. By default the overrides apply to
\code{\link[=theme_ggnext]{theme_ggnext()}}; pass \code{base} to restyle a different preset.
}
\examples{
ggnext(cars, aes(speed, dist)) + geom_point() +
  theme(panel_fill = "#FFF8F0", grid_major_x = FALSE)

# Restyle a preset rather than the default.
ggnext(cars, aes(speed, dist)) + geom_point() +
  theme(base = theme_dark(), plot_title_size = 22)
}
