% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_text}
\alias{geom_text}
\title{Text label layer}
\usage{
geom_text(
  mapping = NULL,
  data = NULL,
  color = NULL,
  fontsize = NULL,
  alpha = NULL,
  anchor = NULL
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}; map \code{label}.}

\item{fontsize}{Font size in px.}

\item{anchor}{\code{"middle"}, \code{"start"}, or \code{"end"}.}
}
\value{
A \link{Layer}.
}
\description{
Text label layer
}
