% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats.R
\name{stat_bin}
\alias{stat_bin}
\title{Bin observations (histogram counts)}
\usage{
stat_bin(bins = 30, binwidth = NULL)
}
\arguments{
\item{bins}{Number of bins (ignored when \code{binwidth} is given).}

\item{binwidth}{Bin width in data units.}
}
\value{
A \code{StatBin} object, to pass as a layer's \code{stat}.
}
\description{
Bin observations (histogram counts)
}
