% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_col}
\alias{geom_col}
\title{Column chart layer (bar heights from the data)}
\usage{
geom_col(
  mapping = NULL,
  data = NULL,
  color = NULL,
  alpha = NULL,
  width = 0.8,
  position = "stack"
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{width}{Bar width as a fraction of the slot.}

\item{position}{\code{"stack"} (default), \code{"dodge"}, or \code{"identity"}.}
}
\value{
A \link{Layer}.
}
\description{
Column chart layer (bar heights from the data)
}
