% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms-special.R
\name{geom_roc}
\alias{geom_roc}
\title{ROC curve layer}
\usage{
geom_roc(
  mapping = NULL,
  data = NULL,
  color = NULL,
  alpha = NULL,
  linewidth = NULL
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{linewidth}{Curve width.}
}
\value{
A \link{Layer}.
}
\description{
Map \code{truth} (actual class; for factors the second level is the positive
class) and \code{score} (predicted score); map \code{color} to compare models.
}
