% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_area}
\alias{geom_area}
\title{Area layer (filled to the zero baseline)}
\usage{
geom_area(mapping = NULL, data = NULL, color = NULL, alpha = NULL)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}
}
\value{
A \link{Layer}.
}
\description{
Area layer (filled to the zero baseline)
}
