% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/labels.R
\name{lims}
\alias{lims}
\title{Set both axis limits at once}
\usage{
lims(x = NULL, y = NULL)
}
\arguments{
\item{x}{Length-2 numeric vector for the x axis, or \code{NULL}.}

\item{y}{Length-2 numeric vector for the y axis, or \code{NULL}.}
}
\value{
A list of scales, which \code{+} adds one at a time.
}
\description{
Set both axis limits at once
}
