% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{coord_cartesian}
\alias{coord_cartesian}
\title{Cartesian coordinate system}
\usage{
coord_cartesian(flip = FALSE)
}
\arguments{
\item{flip}{Swap the x and y axes (horizontal bars, forest plots).}
}
\value{
A \link{CoordCartesian} object to add with \code{+}.
}
\description{
The identity coordinate system.
}
