% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/labels.R
\name{ggtitle}
\alias{ggtitle}
\title{Set the plot title (and optionally the subtitle)}
\usage{
ggtitle(label, subtitle = NULL)
}
\arguments{
\item{label}{Title text.}

\item{subtitle}{Optional subtitle text.}
}
\value{
A \link{Labels} object to add to a plot with \code{+}.
}
\description{
Set the plot title (and optionally the subtitle)
}
