% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms-special.R
\name{geom_dumbbell}
\alias{geom_dumbbell}
\title{Dumbbell layer (before/after per category)}
\usage{
geom_dumbbell(
  mapping = NULL,
  data = NULL,
  color = NULL,
  size = NULL,
  alpha = NULL,
  linewidth = NULL,
  color_start = NULL,
  color_end = NULL
)
}
\arguments{
\item{mapping, data, color, size, alpha}{As in \code{\link[=geom_point]{geom_point()}}; \code{color} styles
the connector.}

\item{linewidth}{Connector width.}

\item{color_start, color_end}{Endpoint dot colors.}
}
\value{
A \link{Layer}.
}
\description{
Map \code{x} (start value), \code{xend} (end value), and \code{y} (category).
}
