% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{ColorScale}
\alias{ColorScale}
\title{ColorScale: palette override for the color aesthetic}
\usage{
ColorScale(palette = character(0), name = NULL, type = character(0))
}
\arguments{
\item{palette}{Character vector of hex colors (two, for a gradient).}

\item{name}{Optional legend title.}

\item{type}{\code{"discrete"} or \code{"continuous"}.}
}
\value{
An S7 object of class \code{ColorScale}; usually built by \code{\link[=scale_color_manual]{scale_color_manual()}} or \code{\link[=scale_color_gradient]{scale_color_gradient()}}.
}
\description{
Created by \code{\link[=scale_color_manual]{scale_color_manual()}} / \code{\link[=scale_color_gradient]{scale_color_gradient()}}.
}
