% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats-clinical.R
\name{stat_coxph}
\alias{stat_coxph}
\title{Hazard ratios from a Cox proportional-hazards model}
\usage{
stat_coxph(ref_level = NULL)
}
\arguments{
\item{ref_level}{Reference level; \code{NULL} uses the first observed value.}
}
\value{
A \code{StatCoxph} object, to pass as a layer's \code{stat}.
}
\description{
Hazard ratios from a Cox proportional-hazards model
}
