% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{theme_dark}
\alias{theme_dark}
\title{Dark theme}
\usage{
theme_dark()
}
\value{
A \link{Theme} to add to a plot with \code{+}.
}
\description{
Dark theme
}
