% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_smooth}
\alias{geom_smooth}
\title{Smoothed trend layer}
\usage{
geom_smooth(
  mapping = NULL,
  data = NULL,
  color = NULL,
  alpha = NULL,
  method = "loess",
  se = TRUE,
  linewidth = NULL,
  level = 0.95
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{method}{\code{"loess"} (default) or \code{"lm"}.}

\item{se}{Draw the confidence band.}

\item{linewidth}{Trend line width.}

\item{level}{Confidence level.}
}
\value{
A \link{Layer}.
}
\description{
Smoothed trend layer
}
