% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_tile}
\alias{geom_tile}
\title{Tile layer (heatmap cells)}
\usage{
geom_tile(
  mapping = NULL,
  data = NULL,
  color = NULL,
  alpha = NULL,
  width = NULL,
  height = NULL
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{width, height}{Tile size in data units (default: data resolution).}
}
\value{
A \link{Layer}.
}
\description{
Map a continuous \code{color} for the classic heatmap look.
}
