% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats-special.R
\name{stat_km_risktable}
\alias{stat_km_risktable}
\title{Number-at-risk table for a Kaplan-Meier curve}
\usage{
stat_km_risktable(breaks = NULL)
}
\arguments{
\item{breaks}{Explicit tick times; \code{NULL} (default) uses \code{pretty()}.}
}
\value{
A \code{StatKMRiskTable} object, to pass as a layer's \code{stat}.
}
\description{
Number-at-risk table for a Kaplan-Meier curve
}
