% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats.R
\name{stat_boxplot}
\alias{stat_boxplot}
\title{Five-number summary for boxplots}
\usage{
stat_boxplot(width = 0.6, coef = 1.5)
}
\arguments{
\item{width}{Box width in x slot units.}

\item{coef}{Whisker length multiplier.}
}
\value{
A \code{StatBoxplot} object, to pass as a layer's \code{stat}.
}
\description{
Five-number summary for boxplots
}
