% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_density}
\alias{geom_density}
\title{Density curve layer}
\usage{
geom_density(
  mapping = NULL,
  data = NULL,
  color = NULL,
  alpha = NULL,
  linewidth = NULL,
  adjust = 1
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}; map only \code{x}.}

\item{linewidth}{Curve stroke width.}

\item{adjust}{Bandwidth multiplier.}
}
\value{
A \link{Layer}.
}
\description{
Density curve layer
}
