% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geoms.R
\name{geom_boxplot}
\alias{geom_boxplot}
\title{Boxplot layer}
\usage{
geom_boxplot(
  mapping = NULL,
  data = NULL,
  color = NULL,
  alpha = NULL,
  width = 0.6,
  coef = 1.5
)
}
\arguments{
\item{mapping, data, color, alpha}{As in \code{\link[=geom_point]{geom_point()}}.}

\item{width}{Box width in x slot units.}

\item{coef}{Whisker length multiplier (Tukey's 1.5 by default).}
}
\value{
A \link{Layer}.
}
\description{
Boxplot layer
}
